match_filter.Party
==================

.. currentmodule:: eqcorrscan.core.match_filter

.. autoclass:: Party

   .. rubric:: Methods

   .. autosummary::

      copy
      filter
      plot
      decluster
      get_catalog
      lag_calc
      min_chans
      read
      rethreshold
      sort
      write

   .. automethod:: __init__
   .. automethod:: copy
   .. automethod:: filter
   .. automethod:: plot
   .. automethod:: decluster
   .. automethod:: get_catalog
   .. automethod:: lag_calc
   .. automethod:: min_chans
   .. automethod:: read
   .. automethod:: rethreshold
   .. automethod:: sort
   .. automethod:: write